4.1. oncilla.buildApi — Oncilla 0.1.0 documentation

# 4.1. oncilla.buildApi

buildApi.py

Platform:
  Windows, Linux, Mac Os X.
Description:
  Builds Sphinx documentation Api files.

Others:

## 4.1.1. Module Attributes

`oncilla.buildApi.` `LOGGER`

`oncilla.buildApi.` `FILES_EXTENSION`

`oncilla.buildApi.` `TOCTREE_TEMPLATE_BEGIN`

`oncilla.buildApi.` `TOCTREE_TEMPLATE_END`

`oncilla.buildApi.` `SANITIZER`

## 4.1.2. Functions

`oncilla.buildApi.` `importSanitizer`(sanitizer)

  Imports the sanitizer python module.

  Parameters: | sanitizer (unicode) – Sanitizer python module file.
  Returns: | Module.
  Return type: | object

`oncilla.buildApi.` `buildApi`(packages, input, output, sanitizer, excludedModules=None)

  Builds the Sphinx documentation API.

  Parameters: | packages (list) – Packages to include in the API. input (unicode) – Input modules directory. output (unicode) – Output reStructuredText files directory. sanitizer (unicode) – Sanitizer python module. excludedModules (list) – Excluded modules.
  Returns: | Definition success.
  Return type: | bool

`oncilla.buildApi.` `getCommandLineArguments`()

  Retrieves command line arguments.

  Returns: | Namespace.
  Return type: | Namespace

`oncilla.buildApi.` `main`()

  Starts the Application.

  Returns: | Definition success.
  Return type: | bool